CCL: pz_params Struct Reference

CCL

Data Fields
pz_params Struct Reference

## Data Fields
double | z_true
user_pz_info * | user_information
int * | status

## Field Documentation

## ◆ status

int* pz_params::status

## ◆ user_information

user_pz_info* pz_params::user_information

## ◆ z_true

double pz_params::z_true

The documentation for this struct was generated from the following file:

- /home/chisarie/Documents/lsst_ccl/CCL/src/ccl_lsst_specs.c